Documentation
¶
Index ¶
Constants ¶
const Eof rune = -1
const Unset rune = -2
Variables ¶
This section is empty.
Functions ¶
func IsAsciiAlpha ¶
Returns true if the current rune is an ASCII letter.
func IsAsciiAlphaNumeric ¶
Returns true if the current rune is an ASCII digit or letter.
func IsAsciiHexDigit ¶
Returns true if the current rune is an hex digit
func IsAsciiLower ¶
Returns true if the current rune is an ASCII lowercase letter.
func IsAsciiNumeric ¶
Returns true if the current rune is an ASCII digit.
func IsAsciiUpper ¶
Returns true if the current rune is an ASCII uppercase letter.
Types ¶
type InputStream ¶
type InputStream struct {
Pos int
// contains filtered or unexported fields
}
func New ¶
func New(input string) InputStream
func (*InputStream) Consume ¶
func (i *InputStream) Consume() rune
func (*InputStream) ConsumeMatch ¶
func (i *InputStream) ConsumeMatch(expected string) bool
Consumes as many bytes as there are in the expected string if the next few codepoints match it case-sensitively.
func (*InputStream) ConsumeMatchIgnoreCase ¶
func (i *InputStream) ConsumeMatchIgnoreCase(expected string) bool
Consumes as many bytes as there are in the expected string if the next few codepoints match it case-insensitively.
func (*InputStream) LookAhead ¶
func (i *InputStream) LookAhead(n uint) string
func (*InputStream) Peek ¶
func (i *InputStream) Peek() rune
func (*InputStream) Reconsume ¶
func (i *InputStream) Reconsume()
Click to show internal directories.
Click to hide internal directories.